# PyQQQ SDK

## 패키지 사용하기

아래 명령을 실행하여 설치할 수 있습니다.

```
pip install pyqqq
```


## 개발 환경 구성하기

0. 가상환경 만들기 (Optional)

아래 방법으로 가상환경을 직접 만들어 사용할 수 있습니다.
```
pyqqq-user:$ cd sdk
pyqqq-user:sdk:$ python -m venv .venv --prompt sdk
pyqqq-user:sdk:$ activate .venv/bin/activate
(sdk) pyqqq-user:sdk:$
```

1. poetry 설치

```
(sdk) pyqqq-user:sdk:$ pip install poetry
```

2. 의존성 갖는 패키지들 설치하기

```
(sdk) pyqqq-user:sdk:$ poetry install
```

